Welcome to ClientVPS Mirrors

Help for package rkafkajars
Type: Package
Title: External Jars Required for Package 'rkafka'
Version: 1.2
Date: 2021-12-01
Author: Shruti Gupta [aut,cre], Coda Hale and Yammer Inc.[ctb,cph],Sun Microsystems Inc.[ctb,cph],Marc Prud'hommeaux[ctb,cph],Paul Holser[ctb],Junit[ctb,cph],The Apache Software Foundation [ctb,cph],Stefan Groschupf[ctb,cph],Taro L.Saito[ctb],EPFL Typesafe Inc.[ctb,cph],QOS.ch[ctb,cph]
Maintainer: Shruti Gupta <shrutigupta34@gmail.com>
Description: The 'rkafkajars' package collects all the external jars required for the 'rkafka' package.
Depends: rJava
Imports: RUnit
SystemRequirements: Java JDK 1.7 or higher
Copyright: See file COPYRIGHTS
License: Apache License 2.0 | file LICENSE
NeedsCompilation: no
Repository: CRAN
Packaged: 2021-12-05 14:42:37 UTC; naveen
Date/Publication: 2021-12-05 16:10:02 UTC

External Jars Required for Package 'rkafka'

Description

The 'rkafkajars' package collects all the external jars required for the 'rkafka' package. These external jars are quite large in size (12MB) and have a slow release cycle. By separating the Java and R development, the storage footprint on CRAN is reduced. By using the 'rJava' package that links R and Java, we can use the excellent work already done by the folks and provide the functionality of using 'KAFKA' in R

Details

Package: rkafkajars
Type: Package
Version: 1.2
Date: 2021-12-01
License: Apache License 2.0

Author(s)

Shruti Gupta

Maintainer: Shruti Gupta<shrutigupta34@gmail.com>

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.